@@ -6,6 +6,8 @@
 
 #include "controller.h"
 
+#include "ktripsettings.h"
+
 #include <QDateTime>
 #include <QDebug>
 #include <QDesktopServices>
@@ -21,6 +23,20 @@ Controller::Controller(QObject *parent)
 {
     m_departureDate = QDate::currentDate();
     m_departureTime = QTime::currentTime();
+    m_manager = std::make_unique<KPublicTransport::Manager>();
+
+    m_firstRun = KTripSettings::firstRun();
+    KTripSettings::setFirstRun(false);
+    KTripSettings::self()->save();
+
+    m_manager->setAllowInsecureBackends(true);
+    m_manager->setBackendsEnabledByDefault(false);
+    m_manager->setEnabledBackends(KTripSettings::self()->enabledBackends());
+
+    connect(m_manager.get(), &KPublicTransport::Manager::configurationChanged, this, [this] {
+        KTripSettings::self()->setEnabledBackends(m_manager->enabledBackends());
+        KTripSettings::self()->save();
+    });
 }
 
 void Controller::setStart(const KPublicTransport::Location &start)
@@ -108,3 +124,13 @@ void Controller::showOnMap(KPublicTransport::Location location)
     QUrl url(QLatin1String("geo:") + QString::number(location.latitude()) + QLatin1Char(',') + QString::number(location.longitude()));
     QDesktopServices::openUrl(url);
 }
+
+bool Controller::firstRun() const
+{
+    return m_firstRun;
+}
+
+KPublicTransport::Manager *Controller::manager() const
+{
+    return m_manager.get();
+}
